<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * HELPER COMMENT START
 * 
 * This is the main class that is responsible for registering
 * the core functions, including the files and setting up all features. 
 * 
 * To add a new class, here's what you need to do: 
 * 1. Add your new class within the following folder: core/includes/classes
 * 2. Create a new variable you want to assign the class to (as e.g. public $helpers)
 * 3. Assign the class within the instance() function ( as e.g. self::$instance->helpers = new Wp_Schema_Injector_Helpers();)
 * 4. Register the class you added to core/includes/classes within the includes() function
 * 
 * HELPER COMMENT END
 */

if ( ! class_exists( 'Wp_Schema_Injector' ) ) :

	/**
	 * Main Wp_Schema_Injector Class.
	 *
	 * @package		WPSCHEMAIN
	 * @subpackage	Classes/Wp_Schema_Injector
	 * @since		1.3
	 * @author		OZAIR WEBS
	 */
	final class Wp_Schema_Injector {

		/**
		 * The real instance
		 *
		 * @access	private
		 * @since	1.3
		 * @var		object|Wp_Schema_Injector
		 */
		private static $instance;

		/**
		 * WPSCHEMAIN helpers object.
		 *
		 * @access	public
		 * @since	1.3
		 * @var		object|Wp_Schema_Injector_Helpers
		 */
		public $helpers;

		/**
		 * WPSCHEMAIN settings object.
		 *
		 * @access	public
		 * @since	1.3
		 * @var		object|Wp_Schema_Injector_Settings
		 */
		public $settings;

		/**
		 * Throw error on object clone.
		 *
		 * Cloning instances of the class is forbidden.
		 *
		 * @access	public
		 * @since	1.3
		 * @return	void
		 */
		public function __clone() {
			_doing_it_wrong( __FUNCTION__, __( 'You are not allowed to clone this class.', 'wp-schema-injector' ), '1.3' );
		}

		/**
		 * Disable unserializing of the class.
		 *
		 * @access	public
		 * @since	1.3
		 * @return	void
		 */
		public function __wakeup() {
			_doing_it_wrong( __FUNCTION__, __( 'You are not allowed to unserialize this class.', 'wp-schema-injector' ), '1.3' );
		}

		/**
		 * Main Wp_Schema_Injector Instance.
		 *
		 * Insures that only one instance of Wp_Schema_Injector exists in memory at any one
		 * time. Also prevents needing to define globals all over the place.
		 *
		 * @access		public
		 * @since		1.3
		 * @static
		 * @return		object|Wp_Schema_Injector	The one true Wp_Schema_Injector
		 */
		public static function instance() {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Wp_Schema_Injector ) ) {
				self::$instance					= new Wp_Schema_Injector;
				self::$instance->base_hooks();
				self::$instance->includes();
				self::$instance->helpers		= new Wp_Schema_Injector_Helpers();
				self::$instance->settings		= new Wp_Schema_Injector_Settings();

				//Fire the plugin logic
				new Wp_Schema_Injector_Run();

				/**
				 * Fire a custom action to allow dependencies
				 * after the successful plugin setup
				 */
				do_action( 'WPSCHEMAIN/plugin_loaded' );
			}

			return self::$instance;
		}

		/**
		 * Include required files.
		 *
		 * @access  private
		 * @since   1.3
		 * @return  void
		 */
		private function includes() {
			require_once WPSCHEMAIN_PLUGIN_DIR . 'core/includes/classes/class-wp-schema-injector-helpers.php';
			require_once WPSCHEMAIN_PLUGIN_DIR . 'core/includes/classes/class-wp-schema-injector-settings.php';

			require_once WPSCHEMAIN_PLUGIN_DIR . 'core/includes/classes/class-wp-schema-injector-run.php';
		}

		/**
		 * Add base hooks for the core functionality
		 *
		 * @access  private
		 * @since   1.3
		 * @return  void
		 */
		private function base_hooks() {
			add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );
		}

		/**
		 * Loads the plugin language files.
		 *
		 * @access  public
		 * @since   1.3
		 * @return  void
		 */
		public function load_textdomain() {
			load_plugin_textdomain( 'wp-schema-injector', FALSE, dirname( plugin_basename( WPSCHEMAIN_PLUGIN_FILE ) ) . '/languages/' );
		}

	}

endif; // End if class_exists check.